===========
bruges
===========

.. image:: https://travis-ci.org/agile-geoscience/bruges.png?branch=master
    :target: https://travis-ci.org/agile-geoscience/bruges
    :alt: Build

.. image:: https://www.codacy.com/project/badge/f445542bc50e48c18a0d0e15a2768eb7
    :target: https://www.codacy.com/public/matt/bruges
    :alt: Codacy

.. image:: https://img.shields.io/badge/license-Apache-blue.svg
    :target: https://github.com/agile-geoscience/bruges/blob/develop/LICENSE.md
    :alt: Apache 2 license

.. image:: http://img.shields.io/pypi/bruges.svg
    :target: http://pypi.python.org/pypi/bruges
    :alt: PyPI downloads
    
.. image:: https://img.shields.io/pypi/v/bruges.svg
    :target: http://pypi.python.org/pypi/bruges/
    :alt: PyPI version
    
.. image:: http://img.shields.io/github/issues/badges/bruges.svg
    :target: https://github.com/agile-geoscience/bruges
    :alt: GitHub issues

.. line-block::
   The bruges module contains several common geophysics functions 
   used for modelling and post-processing seismic reflection data.

Prerequisites
++++++++++++++++
Requires scipy and numpy.

Contributors
++++++++++++
* Evan Bianco
* Ben Bougher
* Matt Hall
* Wes Hamlyn, and Sean Ross-Ross

Links
+++++++
* `Agile Geoscience <http://www.agilegeoscience.com>`_
* `Homepage <http://agile-geoscience.github.com/bruges/>`_
* `Issue Tracker <https://github.com/agile-geoscience/bruges/issues/>`_
* `PyPi <http://pypi.python.org/pypi/bruges/>`_
* `Github <https://github.com/agile-geoscience/bruges>`_
